@@ -1,5 +1,16 @@
 class ConnectionProfile:
+    """
+    ConnectionProfile class is used to store the connection information for the database.
+    """
     def __init__(self, host: str, port: int, database: str, username: str, password: str, sql_type: str):
+        """
+        :param host: Database host
+        :param port: Database port
+        :param database: Database name
+        :param username: Database username
+        :param password: Database password
+        :param sql_type: Database type (sqlite or mysql)
+        """
         self.mysql_host = host
         self.mysql_port = port
         self.mysql_database = database
@@ -8,7 +19,7 @@ class ConnectionProfile:
         self.sql_type = sql_type
         
     @property
-    def connection_uri(self):
+    def connection_uri(self) -> str:
         if self.sql_type == "sqlite":
             uri_elements = [
                 'sqlite:///',
@@ -23,7 +34,7 @@ class ConnectionProfile:
                 '@',
                 self.mysql_host,
                 ':',
-                self.mysql_port,
+                str(self.mysql_port),
                 '/',
                 self.mysql_database
             ]
